#
# spec file for package maven-clean-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-clean-plugin
Version:        3.4.1
Release:        1.1
Summary:        Maven plugin to remove generated files
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-clean-plugin/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{version}/%{name}-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildArch:      noarch

%description
The Maven Clean Plugin is a plugin that removes files generated
at build-time in a project's directory.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package provides %{summary}.

%prep
%setup -q

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE

%changelog
* Wed Feb 19 2025 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.4.1
  * New features and improvements
    + release-drafter configuration
    + Add PR Automation
    + MCLEAN-126: Replaced old File API with new Path equivalent
    where possible
    + Add Release Drafter - 3.x
    + MCLEAN-124: Replaced JUnit Assumptions with @DisabledOnOs
    + MCLEAN-124: Leverage Files.delete(Path) API to provide more
    accurate reason in case of failure
    + MCLEAN-110: Replaced Utils.createSymlink with Java 7
    Files.createSymbolicLink
  * Dependency updates
    + Bump org.apache.maven.resolver:maven-resolver-api from 1.1.1
    to 1.9.22
    + Bump mavenVersion from 3.6.3 to 3.9.9
    + Bump org.codehaus.plexus:plexus-testing from 1.3.0 to 1.4.0
    + Bump org.apache.maven.plugins:maven-plugins from 42 to 43
  * Maintenance
    + Update scm tag according to branch
    + PR Automation only on close event
    + MNGSITE-529: Rename "Goals" to "Plugin Documentation"
    + Fix license/notice
- Older changes
  * Changes of 3.4.0
    + Bump apache/maven-gh-actions-shared from 3 to 4
    + MCLEAN-116: Use default Log interface
    + MCLEAN-118: Require Maven 3.6.3
    + MCLEAN-106: Switch to junit 5
    + MCLEAN-119: Bump org.apache.maven.plugins:maven-plugins from
    41 to 42
    + Build with Maven 4
    + MCLEAN-120: Bump org.codehaus.plexus:plexus-testing from
    1.1.0 to 1.3.0
    + MCLEAN-121: Bump com.google.inject:guice from 4.2.0 to 4.2.3
    + MCLEAN-122: Cleanup declared dependencies, simplify unit test
  * Changes of 3.3.2
    + Type: fill --> file
    + MCLEAN-112: Bump parent to 40
    + MCLEAN-113: Downgrade plexus-xml to 3.0.0
    + Grammar mistake fixed
    + MCLEAN-111: Fix fast delete feature for filesets
    + MCLEAN-114: Refresh download page
  * Changes of 3.3.1
    + MCLEAN-104: Prevent NPE in fast mode and quiet build
    + MCLEAN-105: Bump maven-plugins from 38 to 39
    + MCLEAN-93: Support junctions on NTFS
    + MCLEAN-107: Upgrade to plexus-utils 4.0.0 and plexus-xml 4.0.0
  * Changes of 3.2.0
    + Bump maven-project-info-reports-plugin from 3.1.1 to 3.1.2
    + Bump maven-site-plugin from 3.9.1 to 3.10.0
    + Bump extra-enforcer-rules from 1.4 to 1.5.1
    + MCLEAN-95: Add a fast clean option
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Sun Apr 14 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid trivial name repetition in the summary.
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-clean-plugin 3.1.0
